API
===

Gym Xiangqi provides core environment methods that all OpenAI Gym environments provide.

XiangQiEnv
----------
.. autoclass:: gym_xiangqi.envs.xiangqi_env.XiangQiEnv
  :inherited-members:
  :members: